@@ -207,7 +207,7 @@ def get_by_date_my_buckets(date: str, limit: int, conn: Conn) -> list[FeedEntry]
     return result
 
 
-def conut_by_date_buckets(date: str, buckets: list[str], conn: Conn) -> int:
+def count_by_date_buckets(date: str, buckets: list[str], conn: Conn) -> int:
     total = 0
     for bucket in buckets:
         row = conn.execute(
@@ -220,6 +220,16 @@ def conut_by_date_buckets(date: str, buckets: list[str], conn: Conn) -> int:
     return total
 
 
+def count_all_entries(buckets: list[str], conn: Conn) -> int:
+    total = 0
+    for bucket in buckets:
+        row = conn.execute(stmt.Count_all_entries, (bucket,)).fetchone()
+        if row:
+            total += row[0]
+
+    return total
+
+
 def get_public_limit(cursor: str, limit: int, conn: Conn) -> list[FeedEntry]:
     result: list[FeedEntry] = []
     for row in conn.execute(
